==> owncloud-8.1.0p2.tgz: owncloud/apps/files_external/l10n/hr.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Dohvaćanje tokena zahtjeva nije uspjelo. Provjerite jesu li vaš ključ za aplikacije iz zajedničke mrežne mapei tajna aplikacije ispravni",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Dohvaćanje pristupnog tokena nije uspjelo. Provjerite jesu li vaš ključ za aplikacije iz zajedničke mrežne mapei tajna aplikacije ispravni",
    "Please provide a valid Dropbox app key and secret." : "Molimo navedite ispravan ključ za aplikacije iz zajedničke mrežne mape i tajni kluč.",
    "Step 1 failed. Exception: %s" : "Korak 1 nije uspio. Izuzetak: %s",
    "Step 2 failed. Exception: %s" : "Korak 2 nije uspio. Izuzetak: %s",
    "External storage" : "Vanjsko spremište za pohranu",
    "Local" : "Lokalno",
    "Location" : "Lokacija",
    "Amazon S3" : "Amazon S3",
    "Key" : "Ključ",
    "Secret" : "Tajna",
    "Bucket" : "Kantica",
    "Amazon S3 and compliant" : "Amazon S3 i kompatibilno",
    "Access Key" : "Pristupni ključ",
    "Secret Key" : "Ključ za tajnu",
    "Hostname" : "Naziv poslužitelja",
    "Port" : "Port",
    "Region" : "Regija",
    "Enable SSL" : "Omogućite SSL",
    "Enable Path Style" : "Omogućite Path Style",
    "App key" : "Ključ za aplikacije",
    "App secret" : "Tajna aplikacije",
    "Host" : "Glavno računalo",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Remote subfolder" : "Udaljena podmapa",
    "Secure ftps://" : "Sigurni ftps://",
    "Client ID" : "ID klijenta",
    "Client secret" : "Klijentski tajni ključ",
    "OpenStack Object Storage" : "Prostor za pohranu.....",
    "Region (optional for OpenStack Object Storage)" : "Regija (neobavezno za OpenStack object storage",
    "API Key (required for Rackspace Cloud Files)" : "API ključ (obavezno za Rackspace Cloud Files)",
    "Tenantname (required for OpenStack Object Storage)" : "Naziv korisnika (obavezno za OpenStack Object storage)",
    "Password (required for OpenStack Object Storage)" : "Lozinka (obavezno za OpenStack Object Storage)",
    "Service Name (required for OpenStack Object Storage)" : "Naziv usluge (Obavezno za OpenStack Object Storage)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "URL krajnje točke identiteta (obavezno za OpenStack Object Storage)",
    "Timeout of HTTP requests in seconds" : "Vrijeme isteka HTTP zahtjeva u sekundama",
    "Share" : "Dijeljenje zhajedničkih resursa",
    "SMB / CIFS using OC login" : "SMB / CIFS uz prijavu putem programa OC",
    "Username as share" : "Korisničko ime kao dijeljeni resurs",
    "URL" : "URL",
    "Secure https://" : "Siguran https://",
    "Access granted" : "Pristup odobren",
    "Error configuring Dropbox storage" : "Pogreška pri konfiguriranju spremišta u zajedničkoj mrežnoj mapi",
    "Grant access" : "Dodijeli pristup",
    "Error configuring Google Drive storage" : "Pogreška pri konfiguriranju spremišta u Google Drive-u",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "All users. Type to select user or group." : "Svi korisnici. Započnite unos za izbor korisnika ili grupe.",
    "(group)" : "(grupa)",
    "Saved" : "Spremljeno",
    "<b>Note:</b> " : "<b>Bilješka:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> Podrška cURL u PHP nije omogućena ili nije instalirana. Postavljanje%s nije moguće. Molimo zamolite svog administratora sustava da je instalira.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> Podrška FTP u PHP nije omogućena ili nije instalirana. Postavljanje%s nije moguće. Molimo zamolite svotg administratora sustava da je instalira.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> \"%s\" nije instaliran. Postavljanje %s nije moguće. Molimo zamolitesvog administratora sustava da ga instalira.",
    "Name" : "Naziv",
    "Storage type" : "Vrsta spremišta",
    "Scope" : "Opseg",
    "External Storage" : "Vanjsko spremište",
    "Folder name" : "Naziv mape",
    "Configuration" : "Konfiguracija",
    "Available for" : "Dostupno za",
    "Add storage" : "Dodajte spremište",
    "Delete" : "Izbrišite",
    "Enable User External Storage" : "Omogućite korisničko vanjsko spremište",
    "Allow users to mount the following external storage" : "Dopustite korisnicima postavljanje sljedećeg vanjskog spremišta"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files_external/l10n/hr.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Korak 1 nije uspio. Izuzetak: %s",
    "Step 2 failed. Exception: %s" : "Korak 2 nije uspio. Izuzetak: %s",
    "External storage" : "Vanjsko spremište za pohranu",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Grant access" : "Dodijeli pristup",
    "Access granted" : "Pristup odobren",
    "All users. Type to select user or group." : "Svi korisnici. Započnite unos za izbor korisnika ili grupe.",
    "(group)" : "(grupa)",
    "Saved" : "Spremljeno",
    "None" : "Ništa",
    "App key" : "Ključ za aplikacije",
    "App secret" : "Tajna aplikacije",
    "Client ID" : "ID klijenta",
    "Client secret" : "Klijentski tajni ključ",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Kantica",
    "Hostname" : "Naziv poslužitelja",
    "Port" : "Port",
    "Region" : "Regija",
    "Enable SSL" : "Omogućite SSL",
    "Enable Path Style" : "Omogućite Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Udaljena podmapa",
    "Secure https://" : "Siguran https://",
    "Host" : "Glavno računalo",
    "Secure ftps://" : "Sigurni ftps://",
    "Local" : "Lokalno",
    "Location" : "Lokacija",
    "ownCloud" : "OwnCloud",
    "Root" : "Korijen",
    "Share" : "Dijeljenje zhajedničkih resursa",
    "SMB / CIFS using OC login" : "SMB / CIFS uz prijavu putem programa OC",
    "Username as share" : "Korisničko ime kao dijeljeni resurs",
    "OpenStack Object Storage" : "Prostor za pohranu.....",
    "<b>Note:</b> " : "<b>Bilješka:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> Podrška cURL u PHP nije omogućena ili nije instalirana. Postavljanje%s nije moguće. Molimo zamolite svog administratora sustava da je instalira.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> Podrška FTP u PHP nije omogućena ili nije instalirana. Postavljanje%s nije moguće. Molimo zamolite svotg administratora sustava da je instalira.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> \"%s\" nije instaliran. Postavljanje %s nije moguće. Molimo zamolitesvog administratora sustava da ga instalira.",
    "Name" : "Naziv",
    "Storage type" : "Vrsta spremišta",
    "Scope" : "Opseg",
    "External Storage" : "Vanjsko spremište",
    "Folder name" : "Naziv mape",
    "Configuration" : "Konfiguracija",
    "Available for" : "Dostupno za",
    "Delete" : "Izbrišite",
    "Add storage" : "Dodajte spremište",
    "Enable User External Storage" : "Omogućite korisničko vanjsko spremište",
    "Allow users to mount the following external storage" : "Dopustite korisnicima postavljanje sljedećeg vanjskog spremišta"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
